@@ -109,7 +109,7 @@ class ImageJPython:
         """
         return self._ij.imageDisplay().getActiveDataset()
 
-    def active_imageplus(self, sync=True) -> "jc.ImagePlus":
+    def active_imageplus(self, sync: bool = True) -> "jc.ImagePlus":
         """Get the active ImagePlus image.
 
         Get the active image as an ImagePlus, optionally synchronizing from ImageJ
@@ -279,7 +279,9 @@ class ImageJPython:
             _log_exception(_logger, exc)
             raise exc
 
-    def run_plugin(self, plugin: str, args=None, ij1_style=True, imp=None):
+    def run_plugin(
+        self, plugin: str, args=None, ij1_style: bool = True, imp: "jc.ImagePlus" = None
+    ):
         """Run an ImageJ 1.x plugin.
 
         Run an ImageJ 1.x plugin by specifying the plugin name as a string,
@@ -291,6 +293,7 @@ class ImageJPython:
         :param args: A dictionary of plugin arguments in key: value pairs.
         :param ij1_style: Boolean to set which implicit boolean style to use
             (ImageJ or ImageJ2).
+        :param imp: Optionally: the image to pass to the plugin execution.
 
         :example:
 
@@ -388,13 +391,14 @@ class ImageJPython:
         pyplot.imshow(self.from_java(image), interpolation="nearest", cmap=cmap)
         pyplot.show()
 
-    def sync_image(self, imp: "jc.ImagePlus"):
+    def sync_image(self, imp: "jc.ImagePlus" = None):
         """Synchronize data between ImageJ and ImageJ2.
 
         Synchronize between a Dataset or ImageDisplay linked to an
         ImagePlus by accepting the ImagePlus data as true.
 
-        :param imp: The ImagePlus that needs to be synchronized.
+        :param imp: The ImagePlus that needs to be synchronized,
+                    or None to synchronize ImageJ's active image.
         """
         # This code is necessary because an ImagePlus can sometimes be modified without
         # modifying the linked Dataset/ImageDisplay. This happens when someone uses
@@ -407,11 +411,15 @@ class ImageJPython:
         # such, we only need to make sure that the current 2D image slice is up to
         # date. We do this by manually setting the stack to be the same as the
         # imageprocessor.
+        if imp is None and self._ij.legacy and self._ij.legacy.isActive():
+            imp = self._ij.WindowManager.getCurrentImage()
+        if imp is None:
+            return
         stack = imp.getStack()
         pixels = imp.getProcessor().getPixels()
         stack.setPixels(pixels, imp.getCurrentSlice())
 
-    def to_dataset(self, data):
+    def to_dataset(self, data, dim_order=None):
         """Convert the data into an ImageJ2 Dataset.
 
         Converts a Python image (e.g. xarray or numpy array) or Java image (e.g.
@@ -420,7 +428,6 @@ class ImageJPython:
         :param data: Image object to be converted to Dataset.
         :return: A net.imagej.Dataset.
         """
-        dim_order = None
         if sj.isjava(data):
             if dim_order:
                 _logger.warning(
@@ -439,7 +446,7 @@ class ImageJPython:
 
         raise TypeError(f"Type not supported: {type(data)}")
 
-    def to_img(self, data):
+    def to_img(self, data, dim_order=None):
         """Convert the data into an ImgLib2 Img.
 
         Converts a Python image (e.g. xarray or numpy array) or Java image (e.g.
@@ -448,7 +455,6 @@ class ImageJPython:
         :param data: Image object to be converted to Img.
         :return: A net.imglib2.img.Img.
         """
-        dim_order = None
         if sj.isjava(data):
             if dim_order:
                 _logger.warning(
@@ -492,7 +498,7 @@ class ImageJPython:
 
         return sj.to_java(data, **hints)
 
-    def to_xarray(self, data):
+    def to_xarray(self, data, dim_order=None):
         """Convert the data into an ImgLib2 Img.
 
         Converts a Python image (e.g. xarray or numpy array) or Java image (e.g.
@@ -501,21 +507,24 @@ class ImageJPython:
         :param data: Image object to be converted to xarray.DataArray.
         :return: An xarray.DataArray.
         """
-        dim_order = None
         if sj.isjava(data):
+            if dim_order:
+                _logger.warning(f"Conversion hints are not supported for {type(data)}.")
+            if jc.ImagePlus and isinstance(data, jc.ImagePlus):
+                data = convert.imageplus_to_imgplus(self._ij, data)
             if convert.supports_java_to_xarray(self._ij, data):
-                if dim_order:
-                    _logger.warning(
-                        f"Conversion hints are not supported for {type(data)}."
-                    )
                 return convert.java_to_xarray(self._ij, data)
+            if convert.supports_java_to_ndarray(self._ij, data):
+                return convert.ndarray_to_xarray(
+                    convert.java_to_ndarray(self._ij, data)
+                )
 
         if images.is_xarraylike(data):
             return convert._rename_xarray_dims(data, dim_order)
         if images.is_arraylike(data):
             return convert.ndarray_to_xarray(data, dim_order)
 
-        return TypeError(f"Type not supported: {type(data)}.")
+        raise TypeError(f"Type not supported: {type(data)}.")
 
     # -- Deprecated methods --
 
@@ -1275,6 +1284,11 @@ def _create_gateway():
     ij.py._outputMapper = JavaOutputListener()
     ij.console().addOutputListener(ij.py._outputMapper)
 
+    # Register a Python-side script runner object, used by the
+    # org.scijava:scripting-python script language plugin.
+    if callable(getattr(sj, "enable_python_scripting", None)):
+        sj.enable_python_scripting(ij.context())
+
     sj.when_jvm_stops(lambda: ij.dispose())
 
     return ij
@@ -1325,7 +1339,9 @@ def _create_jvm(
         _logger.debug(
             "List of Maven coordinates given: %s", ij_dir_or_version_or_endpoint
         )
-        if _includes_imagej_legacy(ij_dir_or_version_or_endpoint):
+        if _includes_imagej_legacy(
+            ij_dir_or_version_or_endpoint
+        ) or _includes_imagej_legacy(original_endpoints):
             add_legacy = False
         sj.config.endpoints.extend(ij_dir_or_version_or_endpoint)
 
@@ -1361,7 +1377,9 @@ def _create_jvm(
         _logger.debug("Maven coordinate given: %s", ij_dir_or_version_or_endpoint)
         # Strip whitespace and split concatenated endpoints.
         endpoints = re.sub("\\s*", "", ij_dir_or_version_or_endpoint).split("+")
-        if _includes_imagej_legacy(endpoints):
+        if _includes_imagej_legacy(endpoints) or _includes_imagej_legacy(
+            original_endpoints
+        ):
             add_legacy = False
         sj.config.endpoints.extend(endpoints)
 
@@ -1394,7 +1412,6 @@ def _create_jvm(
         # Add SciJava logging configuration. Without this, we see the warning:
         # SLF4J: Failed to load class "org.slf4j.impl.StaticLoggerBinder".
         # SLF4J: Defaulting to no-operation (NOP) logger implementation
-        # SLF4J: See http://www.slf4j.org/codes.html#StaticLoggerBinder for further details.
         sj.config.endpoints.append("org.scijava:scijava-config:MANAGED")
 
     # Add additional ImageJ endpoints specific to PyImageJ.
